@@ -8,14 +8,14 @@
 #    E-MAIL: prudhomm@mit.edu
 #
 # ORIG-DATE: 28-Oct-01 at 10:01:35
-#  LAST-MOD: 28-Oct-01 at 10:05:27 by Christophe Prud'homme
+#  LAST-MOD: 20-Aug-03 at 09:56:02 by Christophe Prud'homme
 #
 # RCS Infos:
 # ==========
 #    Author: $Author: prudhomm $
-#        Id: $Id: autogen.sh,v 1.1 2001/10/28 15:09:37 prudhomm Exp $
-#  Revision: $Revision: 1.1 $
-#      Date: $Date: 2001/10/28 15:09:37 $
+#        Id: $Id: autogen.sh 206 2006-07-30 16:52:02Z prudhomm $
+#  Revision: $Revision: 206 $
+#      Date: $Date: 2006-07-30 18:52:02 +0200 (Sun, 30 Jul 2006) $
 #    locker: $Locker:  $
 #
 #
@@ -38,14 +38,7 @@
 # DESCRIP-END.
 #
 echo "aclocal -I admin ..." && aclocal -I admin
-if test -x /usr/bin/autoheader2.50; then
-    echo "detected autoheader2.50: autoheader2.50..." && /usr/bin/autoheader2.50
-else
-    echo "autoheader..." && autoheader
-fi
+echo "autoheader..." && autoheader
 echo "automake..." && automake
-if test -x /usr/bin/autoconf2.50; then
-    echo "detected autoconf2.50: autoheader2.50..." && /usr/bin/autoconf2.50
-else
-    echo "autoconf" && autoconf
-fi
\ No newline at end of file
+echo "autoconf..." && autoconf
+
