@@ -9,7 +9,7 @@
 // E-MAIL : prudhomm@users.sourceforge.net
 //
 // ORIG-DATE:     June-94
-// LAST-MOD:     13-Aug-00 at 22:39:48 by Christophe Prud'homme
+// LAST-MOD: 12-Aug-02 at 08:42:57 by Christophe Prud'homme
 //
 // DESCRIPTION:  
 /*
@@ -1173,9 +1173,15 @@ femMesh::renumerotate()
      {
        f = new femPoint[ns];
        for (i = 0; i < ns; ++i)
-	 f[i] = rp[i];
+	 {
+	   f[i][0] = rp[i][0];
+	   f[i][1] = rp[i][1];
+	 }
        for (i = 0; i < ns; ++i)
-	 rp[r[i] - 1] = f[i];
+	 {
+	   rp[r[i] - 1][0] = f[i][0];
+	   rp[r[i] - 1][1] = f[i][1];
+	 }
 
        for (j = 0; j < nt; ++j)
 	 for (i = 0; i < 3; i++)
