@@ -9,7 +9,7 @@
 // E-MAIL :  prudhomm@users.sourceforge.net
 //
 // ORIG-DATE:     June-94
-// LAST-MOD:  8-Oct-01 at 00:19:38 by Christophe Prud'homme
+// LAST-MOD: 24-Oct-01 at 18:49:36 by Christophe Prud'homme
 //
 // DESCRIPTION:  
 /*
@@ -1168,9 +1168,9 @@ femParser::instruction ()
        if (cursym == oldvar)
 	  {
 	    thecst = 1.F;
-	    ofstream        file (thechaine);
+	    std::ofstream        file (thechaine);
 
-	    file << ' ' << endl;
+	    file << ' ' << std::endl;
 	    file.close ();
 	  }			// clean the file
        else
@@ -3412,18 +3412,18 @@ femParser::libere ()
 void 
 femParser::showident (ident * i)
 {
-  cerr << i->name << "\n";
+  std::cout << i->name << "\n";
 }
 
 void 
 femParser::showtreeaux (int level, noeudPtr t)
 {
 //  blanks (level);
-  cerr << mesg[t->symb] << " " << (int)t->symb << "\n";
+  std::cout << mesg[t->symb] << " " << (int)t->symb << "\n";
   if (realpart (t->value))
      {
 //       blanks (level + 1);
-       cerr << realpart (t->value) << "\n";
+       std::cout << realpart (t->value) << "\n";
      }
   if (t->name)
      {
